==> kdesdk-4.6.5.tar.bz2: kdesdk-4.6.5/okteta/kasten/gui/io/streamencoder/srec/bytearraysrecstreamencoderconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, part of the KDE project.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYSRECSTREAMENCODERCONFIGEDITORFACTORY_H
#define BYTEARRAYSRECSTREAMENCODERCONFIGEDITORFACTORY_H

// lib
#include "oktetakastengui_export.h"
// Okteta gui
#include <abstractmodelstreamencoderconfigeditorfactory.h>


namespace Kasten
{

class ByteArraySRecStreamEncoderConfigEditorFactory : public AbstractModelStreamEncoderConfigEditorFactory
{
  public:
    ByteArraySRecStreamEncoderConfigEditorFactory();
    virtual ~ByteArraySRecStreamEncoderConfigEditorFactory();

  public:
    virtual AbstractModelStreamEncoderConfigEditor* tryCreateConfigEditor( AbstractModelStreamEncoder* encoder ) const;
};

}

#endif

==> kdesdk_4.7.1.orig.tar.bz2: kdesdk-4.7.1/okteta/kasten/gui/io/streamencoder/srec/bytearraysrecstreamencoderconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYSRECSTREAMENCODERCONFIGEDITORFACTORY_H
#define BYTEARRAYSRECSTREAMENCODERCONFIGEDITORFACTORY_H

// lib
#include "oktetakastengui_export.h"
// Okteta gui
#include <abstractmodelstreamencoderconfigeditorfactory.h>


namespace Kasten
{

class ByteArraySRecStreamEncoderConfigEditorFactory : public AbstractModelStreamEncoderConfigEditorFactory
{
  public:
    ByteArraySRecStreamEncoderConfigEditorFactory();
    virtual ~ByteArraySRecStreamEncoderConfigEditorFactory();

  public:
    virtual AbstractModelStreamEncoderConfigEditor* tryCreateConfigEditor( AbstractModelStreamEncoder* encoder ) const;
};

}

#endif
